@@ -1,8 +1,7 @@
-unit module SQL;
 use v6;
 use SQL::Lexer;
 
-grammar Basic:ver<0.2.0> is Lexer:ver<0.2.0..*> {
+grammar SQL::Basic:ver<0.2.1> is SQL::Lexer:ver<0.2.1..*> {
     rule TOP {
         \s*
         [   <comment>
